m: Example of accessible areas for a species

mR Documentation

Example of accessible areas for a species

Description

A SpatVector object representing the accessible area for a species.

Format

A SpatVector object.

Value

No return value, used with function vect to bring an example of an accessible area for a species.

Examples

m1 <- terra::vect(system.file("extdata", "m1.gpkg", package = "nichevol"))

terra::plot(m1)

marlonecobos/nichevol documentation built on March 15, 2023, 2:48 p.m.